==> 2.0.0.tar.gz: lib/src/hosted_package_dependency_spec/hosted_package_dependency_spec.dart <==
/*
 * MIT License
 *
 * Copyright (c) 2019 Alexei Sintotski
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

import 'package:functional_data/functional_data.dart' hide Optional;
import 'package:meta/meta.dart';
import 'package:plain_optional/plain_optional.dart';

part 'hosted_package_dependency_spec.g.dart';

// ignore_for_file: annotate_overrides

/// A hosted package is one that can be downloaded from the pub.dev site
/// (or another HTTP server that speaks the same API).
/// https://dart.dev/tools/pub/dependencies
@immutable
@FunctionalData()
class HostedPackageDependencySpec extends $HostedPackageDependencySpec {
  /// Default constructor
  const HostedPackageDependencySpec({
    @required this.package,
    this.version = const Optional.none(),
    this.name = const Optional.none(),
    this.url = const Optional.none(),
  });

  final String package;
  final Optional<String> version;
  final Optional<String> name;
  final Optional<String> url;
}

==> 2.0.1.tar.gz: lib/src/hosted_package_dependency_spec/hosted_package_dependency_spec.dart <==
/*
 * MIT License
 *
 * Copyright (c) 2019 Alexei Sintotski
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

import 'package:functional_data/functional_data.dart';
import 'package:meta/meta.dart';
import 'package:plain_optional/plain_optional.dart';

part 'hosted_package_dependency_spec.g.dart';

// ignore_for_file: annotate_overrides

/// A hosted package is one that can be downloaded from the pub.dev site
/// (or another HTTP server that speaks the same API).
/// https://dart.dev/tools/pub/dependencies
@immutable
@FunctionalData()
class HostedPackageDependencySpec extends $HostedPackageDependencySpec {
  /// Default constructor
  const HostedPackageDependencySpec({
    @required this.package,
    this.version = const Optional.none(),
    this.name = const Optional.none(),
    this.url = const Optional.none(),
  });

  final String package;
  final Optional<String> version;
  final Optional<String> name;
  final Optional<String> url;
}
